==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/Ca_/Cell_/Phich_/NgParameter.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NgParameter:
	"""NgParameter commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Stream, default value after init: Stream.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ngParameter", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_stream_get', 'repcap_stream_set', repcap.Stream.Nr1)

	def clone(self) -> 'NgParameter':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NgParameter(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group

	def repcap_stream_set(self, enum_value: repcap.Stream) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Stream.Default
		Default value after init: Stream.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_stream_get(self) -> repcap.Stream:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, ng_parameter: enums.EutraPhichNg, channel=repcap.Channel.Default, stream=repcap.Stream.Default) -> None:
		"""[SOURce<HW>]:BB:EUTRa:DL:CA:CELL<CH>:PHICh:NGParameter<ST> \n
		Sets the parameter N_g according to . \n
			:param ng_parameter: NG1_6| NG1_2| NG1| NG2| NGCustom NG1_6 | NG1_2 | NG1 | NG2 Determines the number of PHICH groups. NGCustom The number of PHICH groups are set with the command BB:EUTRa:ENCC:NOGRoups.
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'NgParameter')"""
		param = Conversions.enum_scalar_to_str(ng_parameter, enums.EutraPhichNg)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CA:CELL{channel_cmd_val}:PHICh:NGParameter{stream_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default, stream=repcap.Stream.Default) -> enums.EutraPhichNg:
		"""[SOURce<HW>]:BB:EUTRa:DL:CA:CELL<CH>:PHICh:NGParameter<ST> \n
		Sets the parameter N_g according to . \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'NgParameter')
			:return: ng_parameter: NG1_6| NG1_2| NG1| NG2| NGCustom NG1_6 | NG1_2 | NG1 | NG2 Determines the number of PHICH groups. NGCustom The number of PHICH groups are set with the command BB:EUTRa:ENCC:NOGRoups."""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CA:CELL{channel_cmd_val}:PHICh:NGParameter{stream_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPhichNg)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/Ca_/Cell_/Phich_/NgParameter.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NgParameter:
	"""NgParameter commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Stream, default value after init: Stream.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ngParameter", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_stream_get', 'repcap_stream_set', repcap.Stream.Nr1)

	def repcap_stream_set(self, enum_value: repcap.Stream) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Stream.Default
		Default value after init: Stream.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_stream_get(self) -> repcap.Stream:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, ng_parameter: enums.EutraPhichNg, channel=repcap.Channel.Default, stream=repcap.Stream.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CA:CELL<CH>:PHICh:NGParameter<ST> \n
		Snippet: driver.source.bb.eutra.dl.ca.cell.phich.ngParameter.set(ng_parameter = enums.EutraPhichNg.NG1, channel = repcap.Channel.Default, stream = repcap.Stream.Default) \n
		Sets the parameter N_g according to . \n
			:param ng_parameter: NG1_6| NG1_2| NG1| NG2| NGCustom NG1_6 | NG1_2 | NG1 | NG2 Determines the number of PHICH groups. NGCustom The number of PHICH groups are set with the command BB:EUTRa:ENCC:NOGRoups.
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'NgParameter')"""
		param = Conversions.enum_scalar_to_str(ng_parameter, enums.EutraPhichNg)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CA:CELL{channel_cmd_val}:PHICh:NGParameter{stream_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default, stream=repcap.Stream.Default) -> enums.EutraPhichNg:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CA:CELL<CH>:PHICh:NGParameter<ST> \n
		Snippet: value: enums.EutraPhichNg = driver.source.bb.eutra.dl.ca.cell.phich.ngParameter.get(channel = repcap.Channel.Default, stream = repcap.Stream.Default) \n
		Sets the parameter N_g according to . \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'NgParameter')
			:return: ng_parameter: NG1_6| NG1_2| NG1| NG2| NGCustom NG1_6 | NG1_2 | NG1 | NG2 Determines the number of PHICH groups. NGCustom The number of PHICH groups are set with the command BB:EUTRa:ENCC:NOGRoups."""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CA:CELL{channel_cmd_val}:PHICh:NGParameter{stream_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPhichNg)

	def clone(self) -> 'NgParameter':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NgParameter(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
